==========
vdirsyncer
==========

- `Documentation <https://vdirsyncer.pimutils.org/en/stable/>`_
- `Source code <https://github.com/pimutils/vdirsyncer>`_

Vdirsyncer synchronizes your calendars and addressbooks between two
:ref:`storages <storages>`. The most popular purpose is to synchronize a
CalDAV/CardDAV server with a local folder or file. The local data can then be
accessed via a variety of :doc:`programs <supported>`, none of which have to
know or worry about syncing to a server.

It aims to be for CalDAV and CardDAV what `OfflineIMAP
<http://offlineimap.org/>`_ is for IMAP.

.. toctree::
   :caption: Users
   :maxdepth: 1

   when
   tutorial
   ssl-tutorial
   keyring
   config
   supported
   problems

.. toctree::
   :caption: Developers
   :maxdepth: 1

   contributing
   vdir

.. toctree::
   :caption: General
   :maxdepth: 1

   packaging
   contact
   changelog
   license
